@@ -36,7 +36,7 @@ class Users(object):
 		self.visible_email = None
 
 		# system variables.
-		self.verification_codes = {}
+		self.verification_codes = Files.Dictionary(path=None, dictionary={})
 
 		#
 	def get(self, 
@@ -290,13 +290,15 @@ class Users(object):
 		response = self.get(uid=uid, email=email)
 		if response["error"] != None: return response
 		user = response["user"]
-		try: self.verification_codes[mode]
-		except: self.verification_codes[mode] = {}
-		self.verification_codes[mode][user.uid] = {
+		if self.verification_codes.file_path not in [False, None]: self.verification_codes.load()
+		try: self.verification_codes.dictionary[mode]
+		except: self.verification_codes.dictionary[mode] = {}
+		self.verification_codes.dictionary[mode][user.uid] = {
 			"code":code,
 			"stamp":Formats.Date().timestamp,
 			"attempts":3,
 		}
+		if self.verification_codes.file_path not in [False, None]: self.verification_codes.save()
 		
 		# send email.
 		response = self.email.send(
@@ -334,19 +336,22 @@ class Users(object):
 
 		# get success.
 		fail = False
-		try: self.verification_codes[mode]
-		except: self.verification_codes[mode] = {}
-		try: success = self.verification_codes[mode][user.uid]["attempts"] > 0 and str(self.verification_codes[mode][user.uid]["code"]) == str(code)
+		if self.verification_codes.file_path not in [False, None]: self.verification_codes.load()
+		try: self.verification_codes.dictionary[mode]
+		except: self.verification_codes.dictionary[mode] = {}
+		try: success = self.verification_codes.dictionary[mode][user.uid]["attempts"] > 0 and str(self.verification_codes.dictionary[mode][user.uid]["code"]) == str(code)
 		except KeyError: fail = True
 
 		# handle.
 		if fail: 
 			return r3sponse.error_response("Incorrect verification code.")
 		elif not success: 
-			self.verification_codes[mode][user.uid]["attempts"] -= 1
+			self.verification_codes.dictionary[mode][user.uid]["attempts"] -= 1
+			if self.verification_codes.file_path not in [False, None]: self.verification_codes.save()
 			return r3sponse.error_response("Incorrect verification code.")
 		else:
-			del self.verification_codes[mode][user.uid]
+			del self.verification_codes.dictionary[mode][user.uid]
+			if self.verification_codes.file_path not in [False, None]: self.verification_codes.save()
 			return r3sponse.success_response("Successfull verification.")
 
 		#
